Package: DataQualityDashboard
Type: Package
Title: Execute and View Data Quality Checks on OMOP CDM Database
Version: 2.8.9
Date: 2026-05-17
Authors@R: c(
  person("Katy", "Sadowski", email = "sadowski@ohdsi.org", role = c("aut", "cre")),
  person("Clair", "Blacketer", role = c("aut")),
  person("Maxim", "Moinat", role = c("aut")),
  person("Ajit", "Londhe", role = c("aut")),
  person("Anthony", "Sena", role = c("aut")),
  person("Anthony", "Molinaro", role = c("aut")),
  person("Frank", "DeFalco", role = c("aut")),
  person("Pavel", "Grafkin", role = c("aut"))
  )
Author: Katy Sadowski [aut, cre],
  Clair Blacketer [aut],
  Maxim Moinat [aut],
  Ajit Londhe [aut],
  Anthony Sena [aut],
  Anthony Molinaro [aut],
  Frank DeFalco [aut],
  Pavel Grafkin [aut]
Maintainer: Katy Sadowski <sadowski@ohdsi.org>
Description: Assesses data quality in Observational Medical Outcomes Partnership Common Data Model (OMOP CDM) databases. Executes data quality checks and provides an R 'shiny' application to view the results.
License: Apache License 2.0
Config/build/clean-inst-doc: FALSE
VignetteBuilder: knitr
Config/testthat/edition: 3
URL: https://github.com/OHDSI/DataQualityDashboard
BugReports: https://github.com/OHDSI/DataQualityDashboard/issues
Depends: R (>= 3.2.2), DatabaseConnector (>= 2.0.2)
Imports: magrittr, ParallelLogger, dplyr, jsonlite, rJava, SqlRender
        (>= 1.10.1), plyr, stringr, rlang, tidyselect, readr
Suggests: testthat, knitr, rmarkdown, markdown, shiny, ggplot2, Eunomia
        (>= 2.0.0), R.utils, devtools
RoxygenNote: 7.3.2
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-05-18 00:58:09 UTC; katysadowski
Repository: CRAN
Date/Publication: 2026-05-18 07:00:23 UTC
Built: R 4.5.2; ; 2026-05-18 08:56:50 UTC; unix
