% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/executeDqChecks.R
\name{.needsAutoCommit}
\alias{.needsAutoCommit}
\title{Internal function to determine if the connection needs auto commit}
\usage{
.needsAutoCommit(connectionDetails, connection)
}
\arguments{
\item{connectionDetails}{A connectionDetails object for connecting to the CDM database}

\item{connection}{A connection for connecting to the CDM database using the DatabaseConnector::connect(connectionDetails) function.}
}
\value{
A logical value indicating if the connection needs auto commit
}
\description{
Internal function to determine if the connection needs auto commit
}
\keyword{internal}
