% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/recordResult.R
\name{.recordResult}
\alias{.recordResult}
\title{Internal function to put the results of each quality check into a dataframe.}
\usage{
.recordResult(
  result = NULL,
  check,
  checkDescription,
  sql,
  executionTime = NA,
  warning = NA,
  error = NA
)
}
\arguments{
\item{result}{The result of the data quality check}

\item{check}{The data quality check}

\item{checkDescription}{The description of the data quality check}

\item{sql}{The fully qualified sql for the data quality check}

\item{executionTime}{The total time it took to execute the data quality check}

\item{warning}{Any warnings returned from the server}

\item{error}{Any errors returned from the server}
}
\value{
A dataframe containing the check results
}
\description{
Internal function to put the results of each quality check into a dataframe.
}
\keyword{internal}
