% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summarizeResults.R
\name{.summarizeResults}
\alias{.summarizeResults}
\title{Internal function to summarize the results of the DQD run.}
\usage{
.summarizeResults(checkResults)
}
\arguments{
\item{checkResults}{A dataframe containing the results of the checks after running against the database}
}
\value{
A list containing summary statistics of the check results
}
\description{
Internal function to summarize the results of the DQD run.
}
\keyword{internal}
