% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getCheckId.R
\name{.getCheckId}
\alias{.getCheckId}
\title{Internal function to define the id of each check.}
\usage{
.getCheckId(
  checkLevel,
  checkName,
  cdmTableName,
  cdmFieldName = NA,
  conceptId = NA,
  unitConceptId = NA
)
}
\arguments{
\item{checkLevel}{The level of the check. Options are table, field, or concept}

\item{checkName}{The name of the data quality check}

\item{cdmTableName}{The name of the CDM data table the quality check is applied to}

\item{cdmFieldName}{The name of the field in the CDM data table the quality check is applied to}

\item{conceptId}{The concept id the quality check is applied to}

\item{unitConceptId}{The unit concept id the quality check is applied to}
}
\value{
A character string representing the unique check ID
}
\description{
Internal function to define the id of each check.
}
\keyword{internal}
