% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/writeResultsTo.R
\name{.writeResultsToCsv}
\alias{.writeResultsToCsv}
\title{Internal function to write the check results to a csv file.}
\usage{
.writeResultsToCsv(
  checkResults,
  csvPath,
  columns = c("checkId", "failed", "passed", "isError", "notApplicable", "checkName",
    "checkDescription", "thresholdValue", "notesValue", "checkLevel", "category",
    "subcategory", "context", "checkLevel", "cdmTableName", "cdmFieldName", "conceptId",
    "unitConceptId", "numViolatedRows", "pctViolatedRows", "numDenominatorRows",
    "executionTime", "notApplicableReason", "error", "queryText"),
  delimiter = ","
)
}
\arguments{
\item{checkResults}{A dataframe containing the fully summarized data quality check results}

\item{csvPath}{The path where the csv file should be written}

\item{columns}{The columns to be included in the csv file. Default is all columns in the checkResults dataframe.}

\item{delimiter}{The delimiter for the file. Default is comma.}
}
\value{
NULL (writes results to CSV file)
}
\description{
Internal function to write the check results to a csv file.
}
\keyword{internal}
