% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculateNotApplicableStatus.R
\name{.applyNotApplicable}
\alias{.applyNotApplicable}
\title{Applies the 'Not Applicable' status to a single check}
\usage{
.applyNotApplicable(x)
}
\arguments{
\item{x}{Results from a single check}
}
\value{
A numeric value (0 or 1) indicating whether the check is not applicable
}
\description{
Applies the 'Not Applicable' status to a single check
}
\keyword{internal}
