% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/writeJsonResultsTo.R
\name{writeJsonResultsToCsv}
\alias{writeJsonResultsToCsv}
\title{Write JSON Results to CSV file}
\usage{
writeJsonResultsToCsv(
  jsonPath,
  csvPath,
  columns = c("checkId", "failed", "passed", "isError", "notApplicable", "checkName",
    "checkDescription", "thresholdValue", "notesValue", "checkLevel", "category",
    "subcategory", "context", "checkLevel", "cdmTableName", "cdmFieldName", "conceptId",
    "unitConceptId", "numViolatedRows", "pctViolatedRows", "numDenominatorRows",
    "executionTime", "notApplicableReason", "error", "queryText"),
  delimiter = ","
)
}
\arguments{
\item{jsonPath}{Path to the JSON results file generated using the execute function}

\item{csvPath}{Path to the CSV output file}

\item{columns}{(OPTIONAL) List of desired columns}

\item{delimiter}{(OPTIONAL) CSV delimiter}
}
\value{
NULL (writes results to CSV file)
}
\description{
Write JSON Results to CSV file
}
