% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculateNotApplicableStatus.R
\name{.containsNAchecks}
\alias{.containsNAchecks}
\title{Determines if all checks required for 'Not Applicable' status are in the checkNames}
\usage{
.containsNAchecks(checkNames)
}
\arguments{
\item{checkNames}{A character vector of check names}
}
\value{
A logical value indicating whether all required checks are present
}
\description{
Determines if all checks required for 'Not Applicable' status are in the checkNames
}
\keyword{internal}
