% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/writeDBResultsTo.R
\name{writeDBResultsToJson}
\alias{writeDBResultsToJson}
\title{Write DQD results database table to json}
\usage{
writeDBResultsToJson(
  connection,
  resultsDatabaseSchema,
  cdmDatabaseSchema,
  writeTableName,
  outputFolder,
  outputFile
)
}
\arguments{
\item{connection}{A connection object}

\item{resultsDatabaseSchema}{The fully qualified database name of the results schema}

\item{cdmDatabaseSchema}{The fully qualified database name of the CDM schema}

\item{writeTableName}{Name of DQD results table in the database to read from}

\item{outputFolder}{The folder to output the json results file to}

\item{outputFile}{The output filename of the json results file}
}
\value{
NULL (writes results to JSON file)
}
\description{
Write DQD results database table to json
}
