% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculateNotApplicableStatus.R
\name{.hasNAchecks}
\alias{.hasNAchecks}
\title{Determines if all checks are present expected to calculate the 'Not Applicable' status}
\usage{
.hasNAchecks(checkResults)
}
\arguments{
\item{checkResults}{A dataframe containing the results of the data quality checks}
}
\value{
A logical value indicating whether all required checks are present
}
\description{
Determines if all checks are present expected to calculate the 'Not Applicable' status
}
\keyword{internal}
