% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/view.R
\name{viewDqDashboard}
\alias{viewDqDashboard}
\title{View DQ Dashboard}
\usage{
viewDqDashboard(jsonPath, launch.browser = NULL, display.mode = NULL, ...)
}
\arguments{
\item{jsonPath}{The fully-qualified path to the JSON file produced by  \code{\link{executeDqChecks}}}

\item{launch.browser}{Passed on to \code{shiny::runApp}}

\item{display.mode}{Passed on to \code{shiny::runApp}}

\item{...}{Extra parameters for shiny::runApp() like "port" or "host"}
}
\value{
NULL (launches Shiny application)
}
\description{
View DQ Dashboard
}
