% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/listChecks.R
\name{listDqChecks}
\alias{listDqChecks}
\title{List DQ checks}
\usage{
listDqChecks(
  cdmVersion = "5.3",
  tableCheckThresholdLoc = "default",
  fieldCheckThresholdLoc = "default",
  conceptCheckThresholdLoc = "default"
)
}
\arguments{
\item{cdmVersion}{The CDM version to target for the data source. By default, 5.3 is used.}

\item{tableCheckThresholdLoc}{The location of the threshold file for evaluating the table checks. If not specified the default thresholds will be applied.}

\item{fieldCheckThresholdLoc}{The location of the threshold file for evaluating the field checks. If not specified the default thresholds will be applied.}

\item{conceptCheckThresholdLoc}{The location of the threshold file for evaluating the concept checks. If not specified the default thresholds will be applied.}
}
\value{
A list containing check descriptions, table checks, field checks, and concept checks
}
\description{
Details on all checks defined by the DataQualityDashboard Package.
}
