% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/evaluateThresholds.R
\name{.evaluateThresholds}
\alias{.evaluateThresholds}
\title{Internal function to evaluate the data quality checks against given thresholds.}
\usage{
.evaluateThresholds(checkResults, tableChecks, fieldChecks, conceptChecks)
}
\arguments{
\item{checkResults}{A dataframe containing the results of the data quality checks}

\item{tableChecks}{A dataframe containing the table checks}

\item{fieldChecks}{A dataframe containing the field checks}

\item{conceptChecks}{A dataframe containing the concept checks}
}
\value{
A dataframe with updated check results including pass/fail status and threshold values
}
\description{
Internal function to evaluate the data quality checks against given thresholds.
}
\keyword{internal}
