% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculateNotApplicableStatus.R
\name{.calculateNotApplicableStatus}
\alias{.calculateNotApplicableStatus}
\title{Determines if check should be notApplicable and the notApplicableReason}
\usage{
.calculateNotApplicableStatus(checkResults)
}
\arguments{
\item{checkResults}{A dataframe containing the results of the data quality checks}
}
\value{
A dataframe with updated check results including notApplicable status and reasons
}
\description{
Determines if check should be notApplicable and the notApplicableReason
}
\keyword{internal}
