% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readThresholdFile.R
\name{.readThresholdFile}
\alias{.readThresholdFile}
\title{Internal function to read threshold files}
\usage{
.readThresholdFile(checkThresholdLoc, defaultLoc)
}
\arguments{
\item{checkThresholdLoc}{The location of the threshold file}

\item{defaultLoc}{The default location of the threshold file}
}
\value{
A dataframe containing the threshold data
}
\description{
Internal function to read threshold files
}
\keyword{internal}
