% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/writeResultsTo.R
\name{.writeResultsToJson}
\alias{.writeResultsToJson}
\title{Write DQD results to json}
\usage{
.writeResultsToJson(result, outputFolder, outputFile)
}
\arguments{
\item{result}{A DQD results object (list)}

\item{outputFolder}{The output folder}

\item{outputFile}{The output filename}
}
\value{
NULL (writes results to JSON file)
}
\description{
Write DQD results to json
}
\keyword{internal}
