% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/processCheck.R
\name{.processCheck}
\alias{.processCheck}
\title{Internal function to send the fully qualified sql to the database and return the numerical result.}
\usage{
.processCheck(
  connection,
  connectionDetails,
  check,
  checkDescription,
  sql,
  outputFolder
)
}
\arguments{
\item{connection}{A connection for connecting to the CDM database using the DatabaseConnector::connect(connectionDetails) function.}

\item{connectionDetails}{A connectionDetails object for connecting to the CDM database.}

\item{check}{The data quality check}

\item{checkDescription}{The description of the data quality check}

\item{sql}{The fully qualified sql for the data quality check}

\item{outputFolder}{The folder to output logs and SQL files to.}
}
\value{
A dataframe containing the check results
}
\description{
Internal function to send the fully qualified sql to the database and return the numerical result.
}
\keyword{internal}
