% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reEvaluateThresholds.R
\name{reEvaluateThresholds}
\alias{reEvaluateThresholds}
\title{Re-evaluate Thresholds}
\usage{
reEvaluateThresholds(
  jsonFilePath,
  outputFolder,
  outputFile,
  tableCheckThresholdLoc = "default",
  fieldCheckThresholdLoc = "default",
  conceptCheckThresholdLoc = "default",
  cdmVersion = "5.3"
)
}
\arguments{
\item{jsonFilePath}{Path to the JSON results file generated using the execute function}

\item{outputFolder}{The folder to output new JSON result file to}

\item{outputFile}{File to write results JSON object to}

\item{tableCheckThresholdLoc}{The location of the threshold file for evaluating the table checks. If not specified the default thresholds will be applied.}

\item{fieldCheckThresholdLoc}{The location of the threshold file for evaluating the field checks. If not specified the default thresholds will be applied.}

\item{conceptCheckThresholdLoc}{The location of the threshold file for evaluating the concept checks. If not specified the default thresholds will be applied.}

\item{cdmVersion}{The CDM version to target for the data source. By default, 5.3 is used.}
}
\value{
A list containing the re-evaluated DQD results
}
\description{
Re-evaluate an existing DQD result against an updated thresholds file.
}
