% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/writeJsonResultsTo.R
\name{writeJsonResultsToTable}
\alias{writeJsonResultsToTable}
\title{Write JSON Results to SQL Table}
\usage{
writeJsonResultsToTable(
  connectionDetails,
  resultsDatabaseSchema,
  jsonFilePath,
  writeTableName = "dqdashboard_results",
  cohortDefinitionId = c(),
  singleTable = FALSE
)
}
\arguments{
\item{connectionDetails}{A connectionDetails object for connecting to the CDM database}

\item{resultsDatabaseSchema}{The fully qualified database name of the results schema}

\item{jsonFilePath}{Path to the JSON results file generated using the execute function}

\item{writeTableName}{Name of table in the database to write results to}

\item{cohortDefinitionId}{If writing results for a single cohort this is the ID that will be appended to the table name}

\item{singleTable}{If TRUE, writes all results to a single table. If FALSE (default), writes to 3 separate tables by check level (table, field, concept) (NOTE this default behavior will be deprecated in the future)}
}
\value{
NULL (writes results to database table)
}
\description{
Write JSON Results to SQL Table
}
